

# Reading scenarios data --------------------------------------------------
demand_projections_other_scenarios_df <- readr::read_csv("comparison_demand_projections_v1.csv",
                                                         col_types = cols(
                                                           .default = col_number(),
                                                           Mineral = col_character(),
                                                           Ref_number = col_character(),
                                                           Author = col_character(),
                                                           Scope = col_character()
                                                         )) %>% 
  dplyr::rename(`2030` = `2030_kt`,
                `2050` = `2050_kt`) %>% 
  tidyr::pivot_longer(cols = c("2030", "2050"), values_to = "Quantity", names_to = "Year") %>% 
  dplyr::mutate(
    Unit = "kt"
  ) %>% 
  dplyr::mutate(
    Mineral = dplyr::case_when(
      Mineral == "Neodymium" ~ "Rare Earth Elements",
      Mineral == "Dysprosium" ~ "Rare Earth Elements",
      TRUE ~ Mineral
    )
  ) %>% 
  dplyr::group_by(
    Mineral, Ref_number, Author, Scope, Year, Unit
  ) %>% 
  dplyr::summarise(
    Quantity = sum(Quantity)
  ) %>% 
  print()




# Getting lower, higher, and average values to 2050 -----------------------

# low demand
low_res_demand_df <- demand_projections_other_scenarios_df %>% 
  dplyr::filter(Scope == "RES") %>% 
  dplyr::filter(Year == 2050) %>% 
  dplyr::filter(! is.na(Quantity)) %>% 
  dplyr::group_by(Mineral) %>% 
  dplyr::arrange(Quantity, .by_group = TRUE) %>%
  dplyr::filter(dplyr::row_number() == 1) %>% 
  dplyr::mutate(
    Range = "Low"
  ) %>% 
  print()

# high demand
high_res_demand_df <- demand_projections_other_scenarios_df %>% 
  dplyr::filter(Scope == "RES") %>% 
  dplyr::filter(Year == 2050) %>% 
  dplyr::filter(! is.na(Quantity)) %>% 
  dplyr::group_by(Mineral) %>% 
  dplyr::arrange(Quantity, .by_group = TRUE) %>% 
  dplyr::filter(dplyr::row_number() == dplyr::n()) %>% 
  dplyr::mutate(
    Range = "High"
  ) %>% 
  print()

# average demand
avg_res_demand_df <- demand_projections_other_scenarios_df %>% 
  dplyr::filter(Scope == "RES") %>% 
  dplyr::filter(Year == 2050) %>% 
  dplyr::filter(! is.na(Quantity)) %>% 
  dplyr::group_by(Mineral, Year, Unit) %>% 
  dplyr::summarise(
    Quantity = mean(Quantity)
  ) %>% 
  dplyr::mutate(
    Range = "Average"
  ) %>% 
  print()



# Finding Medeas demand - 2015
res_2015_demand_df <- demand_RES_EV_medeas %>% 
  dplyr::filter(Year == 2015) %>% 
  dplyr::filter(Scenario == "GG-100%") %>% 
  dplyr::group_by(Mineral, Scenario, Year, Unit) %>% 
  dplyr::summarise(
    Demand = sum(Demand)
  ) %>%
  dplyr::rename(
    Quantity_2015 = Demand,
    Baseline_2015 = Scenario
  ) %>% 
  dplyr::mutate(
    Quantity_2015 = Quantity_2015 * 1000,
    Unit = "kt",
    Baseline_2015 = "Capellan-Perez-GG-100%",
  ) %>% 
  dplyr::ungroup() %>% 
  dplyr::select(-Year) %>% 
  print()


# Binding them all, for those where no Medeas 2015 data, we set the data to be zero.
range_res_demand_df <- dplyr::bind_rows(low_res_demand_df, high_res_demand_df, avg_res_demand_df) %>% 
  dplyr::select(-Scope) %>% 
  dplyr::mutate(
    Year = as.numeric(Year)
  ) %>% 
  dplyr::left_join(
    res_2015_demand_df,
    by = c("Mineral", "Unit")
  ) %>% 
  dplyr::mutate(
    Quantity_2015 = tidyr::replace_na(Quantity_2015, 0)
  ) %>% 
  tidyr::pivot_longer(
    cols = c("Quantity", "Quantity_2015"), values_to = "Quantity", names_to = ".style"
  ) %>% 
  dplyr::mutate(
    Year = dplyr::case_when(
      .style == "Quantity" ~ 2050,
      .style == "Quantity_2015" ~ 2015
    )
  ) %>% 
  dplyr::select(Mineral, Year, Range, Author, Ref_number, Baseline_2015, Unit, Quantity) %>% 
  print()



# Constructing projections for each year ----------------------------------
check_which_minerals <- range_res_demand_df %>% 
  dplyr::ungroup() %>% 
  dplyr::select(Mineral, Range, Author, Ref_number, Baseline_2015) %>% 
  dplyr::distinct() %>% 
  print()


# expanding minerals
expanding_minerals <- check_which_minerals %>% 
  tidyr::expand_grid(
    Year = seq(2015, 2060)
  ) %>% 
  print()


# For the period 2015-2050, we do interpolation, first value being MEDEAS values

# Joining, and interpolating!
demand_RES_projections_df <- expanding_minerals %>%
  dplyr::left_join(
    range_res_demand_df,
    by = c("Mineral", "Year", "Range", "Author", "Ref_number", "Baseline_2015")
  ) %>%
  dplyr::group_by(Mineral, Range, Author, Ref_number, Baseline_2015) %>%
  dplyr::mutate(
    Demand_RES = zoo::na.approx(Quantity, maxgap = 50, rule = 2) / 1000
  ) %>%
  dplyr::mutate(
    Unit = "Mtons"
  ) %>%
  dplyr::select(-Quantity) %>%
  print()

# Here just doing a test - what happens if demand from RES keeps growing after 2050.
# demand_RES_projections_df <- expanding_minerals %>% 
#   dplyr::left_join(
#     range_res_demand_df,
#     by = c("Mineral", "Year", "Range", "Author", "Ref_number", "Baseline_2015")
#   ) %>% 
#   dplyr::group_by(Mineral, Range, Author, Ref_number, Baseline_2015) %>% 
#   dplyr::mutate(
#     Demand_RES = zoo::na.approx(Quantity, maxgap = 50, rule = 2) / 1000,
#     Demand_RES = dplyr::case_when(
#       Year > 2050 ~ Demand_RES + (Year - 2050) * (dplyr::nth(Demand_RES, n = 2) - dplyr::first(Demand_RES)),
#       TRUE ~ Demand_RES
#     )
#   ) %>% 
#   dplyr::mutate(
#     Unit = "Mtons"
#   ) %>% 
#   dplyr::select(-Quantity) %>% 
#   print()


# Here, we add additional demand from MEDEAS ------------------------------
demand_RES_projections_medeas_df <- all_demand_RES_EV_medeas %>% 
  dplyr::group_by(Mineral, Scenario, Year, Unit) %>% 
  dplyr::summarise(
    Demand_RES = sum(Demand)
  ) %>%
  dplyr::mutate(Year = as.numeric(Year)) %>% 
  dplyr::filter(
    dplyr::between(Year, 2015, 2060)
  ) %>%
  dplyr::mutate(
    Year = as.numeric(Year)
  ) %>% 
  dplyr::mutate(
    Unit = "Mt"
  ) %>% 
  dplyr::mutate(
    Range = dplyr::case_when(
      Scenario == "GG-100%" ~ "High",
      Scenario == "GG-50%" ~ "Low",
      Scenario == "GG-75%" ~ "Average"
    )
  ) %>% 
  dplyr::ungroup() %>% 
  dplyr::select(-Scenario) %>% 
  dplyr::mutate(
    Author = "Capellan-Perez",
    Ref_number = "Dynamic_EROI",
    Baseline_2015 = "Capellan-Perez-GG-100%"
  ) %>% 
  dplyr::relocate(Demand_RES, .after = Baseline_2015) %>% 
  # Need to filter "relevant" minerals. asphalt and bituminen???
  dplyr::filter(
    Mineral %in% c("Aluminium", "Aluminium_mirrors", "Asphalt", "Cement", "Concrete", "Glass", "Glass_reinforcing_plastic",
                   "KNO3_mined", "Iron", "Lime", "Limestone", "Magnesium", "Rock", "Sand and Gravel", 
                   "Soda ash", "Steel", "Titanium", "Titanium mineral concentrates", "Vanadium")
  ) %>%
  dplyr::mutate(
    Demand_RES = dplyr::case_when(
      Mineral == "Asphalt" ~ 0.2 * Demand_RES,
      Mineral == "Concrete" ~ 0.9 * Demand_RES,
      Mineral == "KNO3_mined" ~ 2 * Demand_RES,
      Mineral == "Iron" ~ 1.66 * Demand_RES, # using 60% as average content
      Mineral == "Lime" ~ 2 * Demand_RES,
      Mineral == "Steel" ~ 1.80 * Demand_RES,
      Mineral == "Titanium" ~ 1.66 * 1.66 * Demand_RES, # Ti: 60% of TiO2. Then, Ti mineral concentrate 60% of TiO2.
      TRUE ~ Demand_RES
    )
  ) %>% 
  dplyr::mutate(
    Mineral = dplyr::case_when(
      Mineral == "Aluminium_mirrors" ~ "Aluminium",
      Mineral == "Asphalt" ~ "Sand and Gravel",
      Mineral == "Cement" ~ "Clays",
      Mineral == "Concrete" ~ "Sand and Gravel",
      Mineral == "Glass" ~ 'Sand and Gravel',
      Mineral == "Glass_reinforcing_plastic" ~ "Sand and Gravel",
      Mineral == "KNO3_mined" ~ "Potash",
      Mineral == "Iron" ~ "Iron ore",
      Mineral == "Lime" ~ "Limestone",
      Mineral == "Rock" ~ "Sand and Gravel",
      Mineral == "Steel" ~ "Iron ore",
      Mineral == "Titanium" ~ "Titanium mineral concentrates",
      TRUE ~ Mineral
    )
  ) %>% 
  dplyr::group_by(
    Mineral, Year, Unit, Range, Author, Ref_number, Baseline_2015
  ) %>% 
  dplyr::summarise(
    Demand_RES = sum(Demand_RES)
  ) %>% 
  tidyr::pivot_wider(
    names_from = Range, values_from = Demand_RES
  ) %>% 
  tidyr::pivot_longer(
    cols = c("High", "Low", "Average"), names_to = "Range", values_to = "Demand_RES"
  ) %>% 
  dplyr::mutate(
    Unit = "Mtons"
  ) %>% 
  print()



# All demand projections --------------------------------------------------
all_demand_RES_projections_df <- demand_RES_projections_df %>% 
  dplyr::bind_rows(demand_RES_projections_medeas_df) %>% 
  print()

