

# First, we add demand from RoE to RES ------------------------------------

total_demand_projections_df <- selected_demand_RoE_projections %>% 
  dplyr::filter(Year < 2061) %>% 
  dplyr::mutate(
    Unit = "Mtons"
  ) %>% 
  dplyr::select(
    Mineral, Scenario, Method.used, Method.chosen, Number_past_values, Year, Unit, demand_RoE_Mtons
  ) %>% 
  dplyr::rename(
    Demand_RoE = demand_RoE_Mtons
  ) %>% 
  tidyr::expand_grid(
    Range = c("Low", "High", "Average")
  ) %>% 
  dplyr::left_join(
    all_demand_RES_projections_df,
    by = c("Mineral", "Year", "Unit", "Range")
  ) %>% 
  tidyr::pivot_longer(
    cols = c("Demand_RoE", "Demand_RES"), names_to = "Scope", values_to = "Demand"
  ) %>% 
  dplyr::filter(!is.na(Demand)) %>% 
  dplyr::select(
    Mineral, Scenario, Scope, Method.used, Method.chosen, Number_past_values, Year, Range, Author, Ref_number, Baseline_2015, Unit, Demand
  ) %>% 
  print()




# Second, build recycling rates data frame --------------------------------

rr_scenarios <- tibble(
  RR.scenario = c("Constant", "Moderate", "High"))

# Building all RR scanrios:
recycling_rates_df <- energy_costs_data %>% 
  dplyr::select(Mineral, `Recycling rate`) %>% 
  tidyr::expand_grid(2015:2100) %>% 
  dplyr::rename(Year = `2015:2100`,
                `Initial recycling rate` = `Recycling rate`) %>% 
  dplyr::mutate(
    Constant = `Initial recycling rate`,
    Moderate = `Initial recycling rate` + (Year - 2015) * (1.5 * `Initial recycling rate` - `Initial recycling rate`) / (2060-2015),
    High = dplyr::case_when(
      2 * `Initial recycling rate` >= 0.3 ~ `Initial recycling rate` + (Year - 2015) * `Initial recycling rate` / (2060-2015),
      TRUE ~ `Initial recycling rate` + (Year - 2015) * (0.3 - `Initial recycling rate`) / (2060-2015),
    )
  ) %>% 
  dplyr::select(- `Initial recycling rate`) %>% 
  tidyr::pivot_longer(cols = c("Constant", "Moderate", "High"), values_to = "Recycling rate", names_to = "RR.scenario") %>% 
  dplyr::mutate(
    Year = as.numeric(Year),
    `Recycling rate` = dplyr::case_when(
      `Recycling rate` > 0.8 ~ 0.8,
      TRUE ~ `Recycling rate`
    )
  ) %>% 
  print()


total_production_projections_df <- total_demand_projections_df %>% 
  dplyr::left_join(
    recycling_rates_df,
    by = c("Mineral", "Year")
  ) %>% 
  dplyr::mutate(
    Production = Demand * (1 - `Recycling rate`)
  ) %>% 
  dplyr::relocate(
    RR.scenario, .after = Scenario
  ) %>% 
  print()

