set.seed(123)

# Now run simulation for each mineral.

# Number of draws
# Low, otherwise we'll crash the laptop
NDRAWS <- 1000

# Multiplicative standard deviation
#mstd <- 2 # Means that 68.3% of values are between median/3 and median*3, and 95.5% between median/9 and median*9. Good uncertainty...


# List of minerals considered in the analysis:
mc_mineral_list <- energy_by_mineral_projection_df %>% 
  dplyr::select(Mineral) %>% 
  dplyr::distinct() %>% 
  dplyr::pull()


# # Setting up empty data frame with results for lognormal distribution:
# L_lognorm <- data.frame(matrix(NA, nrow = NDRAWS, ncol = length(mc_mineral_list)))
# colnames(L_lognorm) <- c(mc_mineral_list)
# 
# L_lognorm <- as_tibble(L_lognorm) %>% 
#   dplyr::mutate(Observation = seq(1, NDRAWS)) %>% 
#   dplyr::relocate(Observation, .before = Aluminium)
# 
# 
# # Filling in intensities and L_lognorm data frame:
# for (MINERAL in mc_mineral_list){
#   L_lognorm[, MINERAL] <- rlnorm(n = NDRAWS, 
#                          meanlog = log(final_energy_intensities_default_df[final_energy_intensities_default_df$Mineral == MINERAL, "Final_Intensity_Default"][[1]]),
#                          sdlog = log(sqrt(final_energy_intensities_default_df[final_energy_intensities_default_df$Mineral == MINERAL, "Lognormal_standev_coeff"][[1]])))
# }
# 
# 
# # Checking plot:
# median(L_lognorm[, "Aluminium"][[1]])
# sd(L_lognorm[, "Aluminium"][[1]])
# plot(density(L_lognorm[, "Aluminium"][[1]]))



# Setting up empty data frame with results for normal distribution:
L_norm <- data.frame(matrix(NA, nrow = NDRAWS, ncol = length(mc_mineral_list)))
colnames(L_norm) <- c(mc_mineral_list)

L_norm <- as_tibble(L_norm) %>% 
  dplyr::mutate(Observation = seq(1, NDRAWS)) %>% 
  dplyr::relocate(Observation, .before = Aluminium)


# Filling in intensities and L_lognorm data frame:
for (MINERAL in mc_mineral_list){
  L_norm[, MINERAL] <- rnorm(n = NDRAWS, 
                             mean = final_energy_intensities_default_df[final_energy_intensities_default_df$Mineral == MINERAL, "Final_Intensity_Default"][[1]],
                             sd = final_energy_intensities_default_df[final_energy_intensities_default_df$Mineral == MINERAL, "Normal_standev_coeff"][[1]])
}




# Constructing energy intensities data frame - MC:
energy_intenties_mc_default <- L_norm %>% 
  tidyr::pivot_longer(cols = -Observation, names_to = "Mineral", values_to = "Final_Intensity_Default") %>% 
  dplyr::filter(Observation <= 1000) %>% 
  dplyr::left_join(final_energy_intensities_default_df %>% 
                     dplyr::select(-Lognormal_standev_coeff, -Normal_standev_coeff),
                   by = "Mineral",
                   suffix = c("", "_standard")) %>% 
  dplyr::mutate(
    Final_Intensity_Default = dplyr::case_when(
      Final_Intensity_Default < 0 ~ Final_Intensity_Default_standard,
      TRUE ~ Final_Intensity_Default
    )
  ) %>% 
  dplyr::select(-Final_Intensity_Default_standard) %>% 
  print()



# Historical analysis -----------------------------------------------------
dynamic_energy_intensities_all_years_mc <- energy_intenties_mc_default %>% 
  tidyr::expand_grid(Year = seq(1971, 2015, 1)) %>% 
  print()


# Whole time serie!
energy_consumption_by_mineral_historical_mc <- dynamic_energy_intensities_all_years_mc %>% 
  dplyr::left_join(extraction_df, by = c("Mineral", "Year")) %>% 
  dplyr::mutate(
    Final_Energy_EJ = Extraction * Final_Intensity_Default / 1e9
  ) %>% 
  print()


# Calculating total energy consumption - historical
total_energy_consumption_historical_mc <- energy_consumption_by_mineral_historical_mc %>% 
  dplyr::group_by(Year, Observation) %>% 
  dplyr::summarise(
    Total_Final_Energy_EJ = sum(Final_Energy_EJ)
  ) %>% 
  print()
